summaryrefslogtreecommitdiffstats
path: root/kexi/main/ksplitter.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/main/ksplitter.h')
-rw-r--r--kexi/main/ksplitter.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/main/ksplitter.h b/kexi/main/ksplitter.h
index 47e9307c..05f2d568 100644
--- a/kexi/main/ksplitter.h
+++ b/kexi/main/ksplitter.h
@@ -53,10 +53,10 @@ public:
* Constructor.
* @param parent parent widget
* @param name name
* @param orient orientation. Either @p Qt::Vertical or @p Qt::Horizontal
* @param pos procentual position of the splitter. Must be int [0...100].
*/
- KDockSplitter(TQWidget *parent= 0, const char *name= 0, Qt::Orientation orient=Qt::Vertical, int pos= 50);
+ KDockSplitter(TQWidget *parent= 0, const char *name= 0, TQt::Orientation orient=TQt::Vertical, int pos= 50);
virtual ~KDockSplitter(){};
/**
@@ -169,9 +169,9 @@ public:
void restoreFromForcedFixedSize(KDockWidget *dw);
/**
* The orientation is either @p Qt::Horizontal or @p Qt::Vertical.
*/
- Qt::Orientation orientation(){return m_orientation;}
+ TQt::Orientation orientation(){return m_orientation;}
protected:
friend class KDockContainer;
@@ -223,7 +223,7 @@ private:
* child[01]->getWidget() may be KDockContainer.
*/
TQWidget *child0, *child1;
- Qt::Orientation m_orientation;
+ TQt::Orientation m_orientation;
/**
* If initialised is true, the divider!=0L. If false, the divider==0L!
*/
@@ -235,7 +235,7 @@ private:
TQFrame* divider;
/**
* @p xpos and @p savedXPos represent the current divider position.
- * If the orientation is Qt::Horizontal @p xpos actually is "ypos". So
+ * If the orientation is horizontal @p xpos actually is "ypos". So
* do not get confused only because of the 'x'.
*
* xpos and savedXPos are internally high resolution. So *not* 0..100%
@@ -53,10 +53,10 @@ public:
* @param parent parent widget
* @param name name
- * @param orient orientation. Either @p Qt::Vertical or @p Qt::Horizontal
+ * @param orient orientation. Either @p TQt::Vertical or @p TQt::Horizontal
* @param pos procentual position of the splitter. Must be int [0...100].
*/
@@ -169,9 +169,9 @@ public:
void restoreFromForcedFixedSize(KDockWidget *dw);
/**
- * The orientation is either @p Qt::Horizontal or @p Qt::Vertical.
+ * The orientation is either @p TQt::Horizontal or @p TQt::Vertical.
*/